library(loadeR)
library(ggplot2)
library(RColorBrewer)

#Working directory
setwd("Downloads/")
OUTPUTS <- "~/Downloads/"

#----------------------ANNUAL---------------------#
#Load data
load("series.indices.yr.CMIP6.ssp585.Rdata") #ssp585

indices <- c("wsdi","csdi","tr",
             "r20mm","prcptot","cdd","cwd")

test <- list()
for(i in 1:length(indices)){
  test[[i]] <- list()
  for(m in 1:length(series.indices[[i]])){
    test[[i]][[m]] <- do.call("rbind",series.indices[[i]][[m]])
  }
}

test2 <- list()
for(i in 1:length(indices)){
  test2[[i]] <- do.call("rbind",test[[i]])
}

test3 <- do.call("rbind",test2)

Model <- unique(test3$Model)
Model <- Model[order(Model)]

test3$Model <- factor(test3$Model,levels=rev(Model))
test3$Index <- toupper(test3$Index)
test3$Index <- factor(test3$Index,levels=toupper(c("cdd","cwd","prcptot","r20mm","csdi","wsdi","tr")))

#Ensemble
data <- test3[which(test3$Region=="Catalonia"),]
ensemble <- aggregate(Serie~Index+Year,data,FUN="mean",na.rm=T)
ensemble$Min <- ensemble$Serie - aggregate(Serie~Index+Year,data,FUN="sd",na.rm=T)$Serie
ensemble$Max <- ensemble$Serie + aggregate(Serie~Index+Year,data,FUN="sd",na.rm=T)$Serie

#Plot
png(filename = paste(OUTPUTS,"AnnualIndices_TimeSeries_CMIP6_Catalonia_Historical+SSP585",".png",sep=""),res=300,width=2000,height=3000)
ggplot(data=ensemble,aes(x=Year))  + 
  geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
  geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
  theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
  labs(title = "Annual ETCCDI precipitation and temperature indices over Catalonia ",
         subtitle = "CMIP6 Historical + SSP585. Changes wrt 1981-2010")
dev.off()

#----------------------SEASONAL---------------------#
load("series.indices.mon.CMIP6.ssp585.Rdata") #ssp585
indices <- c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p",
             "rx5day","rx1day")

test <- list()
for(i in 1:length(indices)){
  test[[i]] <- list()
  for(m in 1:length(series.indices[[i]])){
    test[[i]][[m]] <- do.call("rbind",series.indices[[i]][[m]])
  }
}

test2 <- list()
for(i in 1:length(indices)){
  test2[[i]] <- do.call("rbind",test[[i]])
}

test3 <- do.call("rbind",test2)

Model <- unique(test3$Model)
Model <- Model[order(Model)]

test3$Model <- factor(test3$Model,levels=rev(Model))
test3$Index <- toupper(test3$Index)
test3$Index <- factor(test3$Index,levels=toupper(c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p",
                                                   "rx5day","rx1day")))

#Ensemble
data <- test3[which(test3$Region=="Catalonia"),]

#Plot by season
ssn <- c("Winter","Spring","Summer","Autumn")#,"Annual")

for(i in 1:4){
data2 <- data[which(data$Season==ssn[i]),]
ensemble <- aggregate(Serie~Index+Year,data2,FUN="mean",na.rm=T)
ensemble$Min <- ensemble$Serie - aggregate(Serie~Index+Year,data2,FUN="sd",na.rm=T)$Serie
ensemble$Max <- ensemble$Serie + aggregate(Serie~Index+Year,data2,FUN="sd",na.rm=T)$Serie
  
#Temperature indices
ensemble2 <- subset(ensemble,Index%in%toupper(c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p")))
png(filename = paste(OUTPUTS,"SeasonalIndices_",ssn[i],"_TimeSeries_CMIP6_Catalonia_Historical+SSP585",".png",sep=""),res=300,width=2000,height=3000)
ggplot(data=ensemble2,aes(x=Year))  + 
  geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
  geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
  theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
  labs(title = paste(ssn[i]," ETCCDI temperature indices over Catalonia",sep=""),
       subtitle = "CMIP6 Historical + SSP585. Changes wrt 1981-2010")
dev.off()

#Precipitation indices
ensemble2 <- subset(ensemble,Index%in%toupper(c("rx1day","rx5day","tnx","tnn","tx90p","tx10p","tn90p","tn10p")))
png(filename = paste(OUTPUTS,"SeasonalIndices_",ssn[i],"_TimeSeries_CMIP6_Catalonia_Historical+SSP585",".png",sep=""),res=300,width=2000,height=3000)
    ggplot(data=ensemble2,aes(x=Year))  + 
      geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
      geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
      theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
      labs(title = paste(ssn[i]," ETCCDI precpitation indices over Catalonia",sep=""),
           subtitle = "CMIP6 Historical + SSP585. Changes wrt 1981-2010")
    dev.off()
}
